<div align="center">
    <img src="docs/source/logo.svg" width="50%"/>
    </br>
</div>
    
_**L**arge **O**pen **A**ccess **D**atasets for **Ato**mistic **M**aterials **S**cience_

---

![GitHub](https://img.shields.io/github/license/jla-gardner/load-atoms)
![PyPI - Downloads](https://img.shields.io/pypi/dw/load-atoms?color=lavender&label=installs&logo=python&logoColor=white)

Tests:

[![Docs](https://github.com/jla-gardner/load-atoms/actions/workflows/docs.yaml/badge.svg?branch=main)](https://github.com/jla-gardner/load-atoms/actions/workflows/docs.yaml)
[![Tests](https://github.com/jla-gardner/load-atoms/actions/workflows/tests.yaml/badge.svg?branch=main)](https://github.com/jla-gardner/load-atoms/actions/workflows/tests.yaml)
[![codecov](https://codecov.io/github/jla-gardner/load-atoms/branch/main/graph/badge.svg?token=HCVF02CDHR)](https://app.codecov.io/gh/jla-gardner/load-atoms)

# Homepage

https://jla-gardner.github.io/load-atoms/

TODO: write this
